@@ -26,6 +26,7 @@ bool isClean();				// Any changes need to be saved?
 QAction *undoAction(QObject *parent);	// Create an undo action.
 QAction *redoAction(QObject *parent);	// Create an redo action.
 QString changesMade();			// return a string with the texts from all commands on the undo stack -> for commit message
+bool placingCommand();			// Currently executing a new command -> might not have to update the field the user just edited.
 
 // 2) Dive-list related commands
 
@@ -90,10 +91,15 @@ int editDiveSite(struct dive_site *newValue, bool currentDiveOnly);
 int editDiveSiteNew(const QString &newName, bool currentDiveOnly);
 int editTags(const QStringList &newList, bool currentDiveOnly);
 int editBuddies(const QStringList &newList, bool currentDiveOnly);
-int editDiveMaster(const QStringList &newList, bool currentDiveOnly);
+int editDiveGuide(const QStringList &newList, bool currentDiveOnly);
 void pasteDives(const dive *d, dive_components what);
-void replanDive(dive *d); // dive computer(s) and cylinder(s) will be reset!
-void editProfile(dive *d); // dive computer(s) and cylinder(s) will be reset!
+enum class EditProfileType {
+	ADD,
+	REMOVE,
+	MOVE,
+};
+void replanDive(dive *d); // dive computer(s) and cylinder(s) of first argument will be consumed!
+void editProfile(const dive *d, EditProfileType type, int count);
 int addWeight(bool currentDiveOnly);
 int removeWeight(int index, bool currentDiveOnly);
 int editWeight(int index, weightsystem_t ws, bool currentDiveOnly);
@@ -105,6 +111,7 @@ enum class EditCylinderType {
 	GASMIX
 };
 int editCylinder(int index, cylinder_t cyl, EditCylinderType type, bool currentDiveOnly);
+void editSensors(int toCylinder, const int fromCylinder);
 #ifdef SUBSURFACE_MOBILE
 // Edits a dive and creates a divesite (if createDs != NULL) or edits a divesite (if changeDs != NULL).
 // Takes ownership of newDive and createDs!
