@@ -4,6 +4,7 @@
 #include "core/divelist.h"
 #include "core/fulltext.h"
 #include "core/qthelper.h" // for copy_qstring
+#include "core/sample.h"
 #include "core/selection.h"
 #include "core/subsurface-string.h"
 #include "core/tag.h"
@@ -156,7 +157,8 @@ void EditBase<T>::undo()
 	// Send signals.
 	DiveField id = fieldId();
 	emit diveListNotifier.divesChanged(stdToQt<dive *>(dives), id);
-	setSelection(selectedDives, current);
+	if (!placingCommand())
+		setSelection(selectedDives, current);
 }
 
 // We have to manually instantiate the constructors of the EditBase class,
@@ -599,22 +601,22 @@ QString EditBuddies::fieldName() const
 	return Command::Base::tr("buddies");
 }
 
-// ***** DiveMaster *****
-QStringList EditDiveMaster::data(struct dive *d) const
+// ***** DiveGuide *****
+QStringList EditDiveGuide::data(struct dive *d) const
 {
-	return stringToList(d->divemaster);
+	return stringToList(d->diveguide);
 }
 
-void EditDiveMaster::set(struct dive *d, const QStringList &v) const
+void EditDiveGuide::set(struct dive *d, const QStringList &v) const
 {
 	QString text = v.join(", ");
-	free(d->divemaster);
-	d->divemaster = copy_qstring(text);
+	free(d->diveguide);
+	d->diveguide = copy_qstring(text);
 }
 
-QString EditDiveMaster::fieldName() const
+QString EditDiveGuide::fieldName() const
 {
-	return Command::Base::tr("dive master");
+	return Command::Base::tr("dive guide");
 }
 
 static void swapCandQString(QString &q, char *&c)
@@ -632,8 +634,8 @@ PasteState::PasteState(dive *dIn, const dive *data, dive_components what) : d(dI
 	memset(&weightsystems, 0, sizeof(weightsystems));
 	if (what.notes)
 		notes = data->notes;
-	if (what.divemaster)
-		divemaster = data->divemaster;
+	if (what.diveguide)
+		diveguide = data->diveguide;
 	if (what.buddy)
 		buddy = data->buddy;
 	if (what.suit)
@@ -705,8 +707,8 @@ void PasteState::swap(dive_components what)
 {
 	if (what.notes)
 		swapCandQString(notes, d->notes);
-	if (what.divemaster)
-		swapCandQString(divemaster, d->divemaster);
+	if (what.diveguide)
+		swapCandQString(diveguide, d->diveguide);
 	if (what.buddy)
 		swapCandQString(buddy, d->buddy);
 	if (what.suit)
@@ -766,7 +768,7 @@ void PasteDives::undo()
 	// Send signals.
 	DiveField fields(DiveField::NONE);
 	fields.notes = what.notes;
-	fields.divemaster = what.divemaster;
+	fields.diveguide = what.diveguide;
 	fields.buddy = what.buddy;
 	fields.suit = what.suit;
 	fields.rating = what.rating;
@@ -793,7 +795,7 @@ void PasteDives::redo()
 }
 
 // ***** ReplanDive *****
-ReplanDive::ReplanDive(dive *source, bool edit_profile) : d(current_dive),
+ReplanDive::ReplanDive(dive *source) : d(current_dive),
 	when(0),
 	maxdepth({0}),
 	meandepth({0}),
@@ -823,7 +825,7 @@ ReplanDive::ReplanDive(dive *source, bool edit_profile) : d(current_dive),
 	std::swap(source->cylinders, cylinders);
 	std::swap(source->dc, dc);
 
-	setText((edit_profile ? Command::Base::tr("Replan dive") : Command::Base::tr("Edit profile")) + diveNumberOrDate(d));
+	setText(Command::Base::tr("Replan dive"));
 }
 
 ReplanDive::~ReplanDive()
@@ -858,6 +860,8 @@ void ReplanDive::undo()
 	emit diveListNotifier.cylindersReset(divesToNotify);
 	emit diveListNotifier.divesChanged(divesToNotify, DiveField::DATETIME | DiveField::DURATION | DiveField::DEPTH | DiveField::MODE |
 							  DiveField::NOTES | DiveField::SALINITY | DiveField::ATM_PRESS);
+	if (!placingCommand())
+		setSelection({ d }, d);
 }
 
 // Redo and undo do the same
@@ -866,6 +870,79 @@ void ReplanDive::redo()
 	undo();
 }
 
+// ***** EditProfile *****
+QString editProfileTypeToString(EditProfileType type, int count)
+{
+	switch (type) {
+		default:
+		case EditProfileType::ADD: return Command::Base::tr("Add stop");
+		case EditProfileType::REMOVE: return Command::Base::tr("Remove %n stop(s)", "", count);
+		case EditProfileType::MOVE: return Command::Base::tr("Move %n stop(s)", "", count);
+	}
+}
+
+EditProfile::EditProfile(const dive *source, EditProfileType type, int count) : d(current_dive),
+	dcNr(dc_number),
+	maxdepth({0}),
+	meandepth({0}),
+	dcmaxdepth({0}),
+	duration({0}),
+	dc({ 0 })
+{
+	const struct divecomputer *sdc = get_dive_dc_const(source, dcNr);
+	if (!sdc)
+		d = nullptr; // Signal that we refuse to do anything.
+	if (!d)
+		return;
+
+	maxdepth = source->maxdepth;
+	dcmaxdepth = sdc->maxdepth;
+	meandepth = source->meandepth;
+	duration = source->duration;
+
+	copy_samples(sdc, &dc);
+	copy_events(sdc, &dc);
+
+	setText(editProfileTypeToString(type, count) + diveNumberOrDate(d));
+}
+
+EditProfile::~EditProfile()
+{
+	free_dive_dcs(&dc);
+}
+
+bool EditProfile::workToBeDone()
+{
+	return !!d;
+}
+
+void EditProfile::undo()
+{
+	struct divecomputer *sdc = get_dive_dc(d, dcNr);
+	if (!sdc)
+		return;
+	std::swap(sdc->samples, dc.samples);
+	std::swap(sdc->alloc_samples, dc.alloc_samples);
+	std::swap(sdc->sample, dc.sample);
+	std::swap(sdc->maxdepth, dc.maxdepth);
+	std::swap(d->maxdepth, maxdepth);
+	std::swap(d->meandepth, meandepth);
+	std::swap(d->duration, duration);
+	fixup_dive(d);
+	invalidate_dive_cache(d); // Ensure that dive is written in git_save()
+
+	QVector<dive *> divesToNotify = { d };
+	emit diveListNotifier.divesChanged(divesToNotify, DiveField::DURATION | DiveField::DEPTH);
+	if (!placingCommand())
+		setSelection({ d }, d);
+}
+
+// Redo and undo do the same
+void EditProfile::redo()
+{
+	undo();
+}
+
 // ***** Add Weight *****
 AddWeight::AddWeight(bool currentDiveOnly) :
 	EditDivesBase(currentDiveOnly)
@@ -1284,6 +1361,43 @@ void EditCylinder::undo()
 	redo();
 }
 
+EditSensors::EditSensors(int toCylinderIn, int fromCylinderIn)
+	: d(current_dive), dc(get_dive_dc(d, dc_number)), toCylinder(toCylinderIn), fromCylinder(fromCylinderIn)
+{
+	if (!d || !dc)
+		return;
+
+	setText(Command::Base::tr("Edit sensors"));
+
+}
+
+void EditSensors::mapSensors(int toCyl, int fromCyl)
+{
+	for (int i = 0; i < dc->samples; ++i) {
+		for (int s = 0; s < MAX_SENSORS; ++s) {
+			if (dc->sample[i].pressure[s].mbar && dc->sample[i].sensor[s] == fromCyl)
+				dc->sample[i].sensor[s] = toCyl;
+		}
+	}
+	emit diveListNotifier.diveComputerEdited(dc);
+	invalidate_dive_cache(d); // Ensure that dive is written in git_save()
+}
+
+void EditSensors::undo()
+{
+	mapSensors(fromCylinder, toCylinder);
+}
+
+void EditSensors::redo()
+{
+	mapSensors(toCylinder, fromCylinder);
+}
+
+bool EditSensors::workToBeDone()
+{
+	return d && dc;
+}
+
 #ifdef SUBSURFACE_MOBILE
 
 EditDive::EditDive(dive *oldDiveIn, dive *newDiveIn, dive_site *createDs, dive_site *editDs, location_t dsLocationIn)
@@ -1321,8 +1435,8 @@ EditDive::EditDive(dive *oldDiveIn, dive *newDiveIn, dive_site *createDs, dive_s
 		changedFields |= DiveField::ATM_PRESS;
 	if (oldDive->dive_site != newDive->dive_site)
 		changedFields |= DiveField::DIVESITE;
-	if (!same_string(oldDive->divemaster, newDive->divemaster))
-		changedFields |= DiveField::DIVEMASTER;
+	if (!same_string(oldDive->diveguide, newDive->diveguide))
+		changedFields |= DiveField::DIVEGUIDE;
 	if (!same_string(oldDive->buddy, newDive->buddy))
 		changedFields |= DiveField::BUDDY;
 	if (oldDive->rating != newDive->rating)
