@@ -5,10 +5,6 @@
 
 static const QString group = QStringLiteral("Planner");
 
-qPrefDivePlanner::qPrefDivePlanner(QObject *parent) : QObject(parent)
-{
-}
-
 qPrefDivePlanner *qPrefDivePlanner::instance()
 {
 	static qPrefDivePlanner *self = new qPrefDivePlanner;
@@ -35,6 +31,7 @@ void qPrefDivePlanner::loadSync(bool doSync)
 	disk_display_variations(doSync);
 	disk_doo2breaks(doSync);
 	disk_dobailout(doSync);
+	disk_o2narcotic(doSync);
 	disk_drop_stone_mode(doSync);
 	disk_last_stop(doSync);
 	disk_min_switch_duration(doSync);
@@ -76,6 +73,7 @@ HANDLE_PREFERENCE_BOOL(DivePlanner, "display_variations", display_variations);
 
 HANDLE_PREFERENCE_BOOL(DivePlanner, "doo2breaks", doo2breaks);
 HANDLE_PREFERENCE_BOOL(DivePlanner, "dobailbout", dobailout);
+HANDLE_PREFERENCE_BOOL(DivePlanner, "o2narcotic", o2narcotic);
 
 HANDLE_PREFERENCE_BOOL(DivePlanner, "drop_stone_mode", drop_stone_mode);
 
