@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "desktop-widgets/downloadfromdivecomputer.h"
 #include "commands/command.h"
-#include "core/display.h"
 #include "core/qthelper.h"
 #include "core/divelist.h"
 #include "core/settings/qPrefDiveComputer.h"
@@ -31,8 +30,8 @@ DownloadFromDCWidget::DownloadFromDCWidget(QWidget *parent) : QDialog(parent, QF
 {
 	diveImportedModel = new DiveImportedModel(this);
 	vendorModel.setStringList(vendorList);
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), this);
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), this);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this);
 
 	int startingWidth = defaultModelFont().pointSize();
 
@@ -311,7 +310,7 @@ void DownloadFromDCWidget::updateState(states state)
 	currentState = state;
 }
 
-void DownloadFromDCWidget::on_vendor_currentIndexChanged(const QString &vendor)
+void DownloadFromDCWidget::on_vendor_currentTextChanged(const QString &vendor)
 {
 	unsigned int transport;
 	dc_descriptor_t *descriptor;
@@ -323,7 +322,7 @@ void DownloadFromDCWidget::on_vendor_currentIndexChanged(const QString &vendor)
 	fill_device_list(transport);
 }
 
-void DownloadFromDCWidget::on_product_currentIndexChanged(const QString &)
+void DownloadFromDCWidget::on_product_currentTextChanged(const QString &)
 {
 	updateDeviceEnabled();
 }
