@@ -502,6 +502,12 @@ QVariant TemplateLayout::getValue(QString list, QString property, const State &s
 			return get_pressure_string(cylinder->end, true);
 		} else if (property == "gasMix") {
 			return get_gas_string(cylinder->gasmix);
+                } else if (property == "gasO2") {
+                        return (get_o2(cylinder->gasmix) + 5) / 10;
+                } else if (property == "gasN2") {
+                        return (get_n2(cylinder->gasmix) + 5) / 10;
+                } else if (property == "gasHe") {
+                        return (get_he(cylinder->gasmix) + 5) / 10;
 		}
 	} else if (list == "dives") {
 		if (!state.currentDive)
@@ -541,8 +547,12 @@ QVariant TemplateLayout::getValue(QString list, QString property, const State &s
 			return d->duration.seconds == 0 && d->dc.duration.seconds == 0;
 		} else if (property == "depth") {
 			return get_depth_string(d->dc.maxdepth.mm, true, true);
+		} else if (property == "meandepth") {
+			return get_depth_string(d->dc.meandepth.mm, true, true);
 		} else if (property == "divemaster") {
-			return d->divemaster;
+			return d->diveguide;
+		} else if (property == "diveguide") {
+			return d->diveguide;
 		} else if (property == "buddy") {
 			return d->buddy;
 		} else if (property == "airTemp") {
