@@ -12,13 +12,13 @@ if [[ $(pwd | grep "subsurface$") || ! -d subsurface || ! -d subsurface/libdivec
 	exit 1;
 fi
 if [[ ! -d googlemaps ]] ; then
-	echo "Please make sure you have the current master of git://github.com/Subsurface/googlemaps"
+	echo "Please make sure you have the current master of https://github.com/Subsurface/googlemaps"
 	echo "checked out in parallel to the Subsurface directory"
 	exit 1;
 fi
 
 if [[ ! -d libgit2 ]] ; then
-	echo "Please make sure you have libgit2 1.0 from git://github.com/libgit2/libgit2"
+	echo "Please make sure you have libgit2 1.0 from https://github.com/libgit2/libgit2"
 	echo "checked out in parallel to the Subsurface directory"
 	exit 1;
 fi
@@ -117,7 +117,7 @@ debuild -S -d
 # file when building the newer ones
 sed -i.bak "/qt5-default/d" debian/control
 rel=bionic
-others="focal hirsute impish"
+others="focal impish jammy"
 for next in $others
 do
 	sed -i "s/${rel}/${next}/g" debian/changelog
