@@ -1,38 +1,33 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "profile-widget/diveeventitem.h"
-#include "qt-models/diveplotdatamodel.h"
 #include "profile-widget/divecartesianaxis.h"
+#include "profile-widget/divepixmapcache.h"
 #include "profile-widget/animationfunctions.h"
 #include "core/event.h"
 #include "core/format.h"
-#include "core/libdivecomputer.h"
 #include "core/profile.h"
 #include "core/gettextfromc.h"
-#include "core/metrics.h"
 #include "core/sample.h"
 #include "core/subsurface-string.h"
-#include <QDebug>
 
 #define DEPTH_NOT_FOUND (-2342)
 
+static int depthAtTime(const plot_info &pi, duration_t time);
+
 DiveEventItem::DiveEventItem(const struct dive *d, struct event *ev, struct gasmix lastgasmix,
-			     DivePlotDataModel *model, DiveCartesianAxis *hAxis, DiveCartesianAxis *vAxis,
-			     int speed, double fontPrintScale, QGraphicsItem *parent) : DivePixmapItem(parent),
+			     const plot_info &pi, DiveCartesianAxis *hAxis, DiveCartesianAxis *vAxis,
+			     int speed, const DivePixmaps &pixmaps, QGraphicsItem *parent) : DivePixmapItem(parent),
 	vAxis(vAxis),
 	hAxis(hAxis),
-	dataModel(model),
 	ev(ev),
-	dive(d)
+	dive(d),
+	depth(depthAtTime(pi, ev->time))
 {
 	setFlag(ItemIgnoresTransformations);
 
-	setupPixmap(lastgasmix, fontPrintScale);
+	setupPixmap(lastgasmix, pixmaps);
 	setupToolTipString(lastgasmix);
-	recalculatePos(0);
-
-
-	connect(vAxis, &DiveCartesianAxis::sizeChanged, this,
-		[speed, this] { recalculatePos(speed); });
+	recalculatePos();
 }
 
 DiveEventItem::~DiveEventItem()
@@ -49,62 +44,42 @@ struct event *DiveEventItem::getEventMutable()
 	return ev;
 }
 
-void DiveEventItem::setupPixmap(struct gasmix lastgasmix, double fontPrintScale)
+void DiveEventItem::setupPixmap(struct gasmix lastgasmix, const DivePixmaps &pixmaps)
 {
-	extern int verbose;
-	const IconMetrics& metrics = defaultIconMetrics();
-#ifndef SUBSURFACE_MOBILE
-	int sz_bigger = metrics.sz_med + metrics.sz_small; // ex 40px
-#else
-#if defined(Q_OS_IOS)
-	 // on iOS devices we need to adjust for Device Pixel Ratio
-	int sz_bigger = metrics.sz_med  * metrics.dpr;
-#else
-	// SUBSURFACE_MOBILE, seems a little big from the code,
-	// but looks fine on device
-	int sz_bigger = metrics.sz_big + metrics.sz_med;
-#endif
-#endif
-	sz_bigger = lrint(sz_bigger * fontPrintScale);
-	int sz_pix = sz_bigger/2; // ex 20px
-	if (verbose)
-		qDebug() << __FUNCTION__ << "fontPrintScale" << fontPrintScale << "metrics" << metrics.sz_med << metrics.sz_small << "sz_bigger" << sz_bigger;
-
-#define EVENT_PIXMAP(PIX) QPixmap(QString(PIX)).scaled(sz_pix, sz_pix, Qt::KeepAspectRatio, Qt::SmoothTransformation)
-#define EVENT_PIXMAP_BIGGER(PIX) QPixmap(QString(PIX)).scaled(sz_bigger, sz_bigger, Qt::KeepAspectRatio, Qt::SmoothTransformation)
 	if (empty_string(ev->name)) {
-		setPixmap(EVENT_PIXMAP(":status-warning-icon"));
+		setPixmap(pixmaps.warning);
 	} else if (same_string_caseinsensitive(ev->name, "modechange")) {
 		if (ev->value == 0)
-			setPixmap(EVENT_PIXMAP(":bailout-icon"));
+			setPixmap(pixmaps.bailout);
 		else
-			setPixmap(EVENT_PIXMAP(":onCCRLoop-icon"));
+			setPixmap(pixmaps.onCCRLoop);
 	} else if (ev->type == SAMPLE_EVENT_BOOKMARK) {
-		setPixmap(EVENT_PIXMAP(":dive-bookmark-icon"));
+		setPixmap(pixmaps.bookmark);
+		setOffset(QPointF(0.0, -pixmap().height()));
 	} else if (event_is_gaschange(ev)) {
 		struct gasmix mix = get_gasmix_from_event(dive, ev);
 		struct icd_data icd_data;
 		bool icd = isobaric_counterdiffusion(lastgasmix, mix, &icd_data);
 		if (mix.he.permille) {
 			if (icd)
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-trimix-ICD-icon"));
+				setPixmap(pixmaps.gaschangeTrimixICD);
 			else
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-trimix-icon"));
+				setPixmap(pixmaps.gaschangeTrimix);
 		} else if (gasmix_is_air(mix)) {
 			if (icd)
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-air-ICD-icon"));
+				setPixmap(pixmaps.gaschangeAirICD);
 			else
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-air-icon"));
+				setPixmap(pixmaps.gaschangeAir);
 		} else if (mix.o2.permille == 1000) {
 			if (icd)
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-oxygen-ICD-icon"));
+				setPixmap(pixmaps.gaschangeOxygenICD);
 			else
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-oxygen-icon"));
+				setPixmap(pixmaps.gaschangeOxygen);
 		} else {
 			if (icd)
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-ean-ICD-icon"));
+				setPixmap(pixmaps.gaschangeEANICD);
 			else
-				setPixmap(EVENT_PIXMAP_BIGGER(":gaschange-ean-icon"));
+				setPixmap(pixmaps.gaschangeEAN);
 		}
 #ifdef SAMPLE_FLAGS_SEVERITY_SHIFT
 	} else if ((((ev->flags & SAMPLE_FLAGS_SEVERITY_MASK) >> SAMPLE_FLAGS_SEVERITY_SHIFT) == 1) ||
@@ -121,16 +96,14 @@ void DiveEventItem::setupPixmap(struct gasmix lastgasmix, double fontPrintScale)
 		// so set an "almost invisible" pixmap (a narrow but somewhat tall, basically transparent pixmap)
 		// that allows tooltips to work when we don't want to show a specific
 		// pixmap for an event, but want to show the event value in the tooltip
-		QPixmap transparentPixmap(4, 20);
-		transparentPixmap.fill(QColor::fromRgbF(1.0, 1.0, 1.0, 0.01));
-		setPixmap(transparentPixmap);
+		setPixmap(pixmaps.transparent);
 #ifdef SAMPLE_FLAGS_SEVERITY_SHIFT
 	} else if (((ev->flags & SAMPLE_FLAGS_SEVERITY_MASK) >> SAMPLE_FLAGS_SEVERITY_SHIFT) == 2) {
-		setPixmap(EVENT_PIXMAP(":status-info-icon"));
+		setPixmap(pixmaps.info);
 	} else if (((ev->flags & SAMPLE_FLAGS_SEVERITY_MASK) >> SAMPLE_FLAGS_SEVERITY_SHIFT) == 3) {
-		setPixmap(EVENT_PIXMAP(":status-warning-icon"));
+		setPixmap(pixmaps.warning);
 	} else if (((ev->flags & SAMPLE_FLAGS_SEVERITY_MASK) >> SAMPLE_FLAGS_SEVERITY_SHIFT) == 4) {
-		setPixmap(EVENT_PIXMAP(":status-violation-icon"));
+		setPixmap(pixmaps.violation);
 #endif
 	} else if (same_string_caseinsensitive(ev->name, "violation") || // generic libdivecomputer
 		   same_string_caseinsensitive(ev->name, "Safety stop violation")  || // the rest are from the Uemis downloader
@@ -139,20 +112,18 @@ void DiveEventItem::setupPixmap(struct gasmix lastgasmix, double fontPrintScale)
 		   same_string_caseinsensitive(ev->name, "Dive time alert")  ||
 		   same_string_caseinsensitive(ev->name, "Low battery alert")  ||
 		   same_string_caseinsensitive(ev->name, "Speed alarm")) {
-		setPixmap(EVENT_PIXMAP(":status-violation-icon"));
+		setPixmap(pixmaps.violation);
 	} else if (same_string_caseinsensitive(ev->name, "non stop time") || // generic libdivecomputer
 		   same_string_caseinsensitive(ev->name, "safety stop") ||
 		   same_string_caseinsensitive(ev->name, "safety stop (voluntary)") ||
 		   same_string_caseinsensitive(ev->name, "Tank change suggested") || // Uemis downloader
 		   same_string_caseinsensitive(ev->name, "Marker")) {
-		setPixmap(EVENT_PIXMAP(":status-info-icon"));
+		setPixmap(pixmaps.info);
 	} else {
 		// we should do some guessing based on the type / name of the event;
 		// for now they all get the warning icon
-		setPixmap(EVENT_PIXMAP(":status-warning-icon"));
+		setPixmap(pixmaps.warning);
 	}
-#undef EVENT_PIXMAP
-#undef EVENT_PIXMAP_BIGGER
 }
 
 void DiveEventItem::setupToolTipString(struct gasmix lastgasmix)
@@ -207,9 +178,27 @@ void DiveEventItem::eventVisibilityChanged(const QString&, bool)
 	//WARN: lookslike we should implement this.
 }
 
-bool DiveEventItem::shouldBeHidden()
+static int depthAtTime(const plot_info &pi, duration_t time)
 {
-	const struct divecomputer *dc = get_dive_dc_const(dive, dc_number);
+	// Do a binary search for the timestamp
+	auto it = std::lower_bound(pi.entry, pi.entry + pi.nr, time,
+				   [](const plot_data &d1, duration_t t) { return d1.sec < t.seconds; });
+	if (it == pi.entry + pi.nr || it->sec != time.seconds) {
+		qWarning("can't find a spot in the dataModel");
+		return DEPTH_NOT_FOUND;
+	}
+	return it->depth;
+}
+
+bool DiveEventItem::isInteresting(const struct dive *d, const struct divecomputer *dc,
+				  const struct event *ev, const plot_info &pi,
+				  int firstSecond, int lastSecond)
+{
+	/*
+	 * Ignore items outside of plot range
+	 */
+	if (ev->time.seconds < firstSecond || ev->time.seconds >= lastSecond)
+		return false;
 
 	/*
 	 * Some gas change events are special. Some dive computers just tell us the initial gas this way.
@@ -219,8 +208,8 @@ bool DiveEventItem::shouldBeHidden()
 	if (!strcmp(ev->name, "gaschange") &&
 	    (ev->time.seconds == 0 ||
 	     (first_sample && ev->time.seconds == first_sample->time.seconds) ||
-	     depthAtTime(ev->time.seconds) < SURFACE_THRESHOLD))
-		return true;
+	     depthAtTime(pi, ev->time) < SURFACE_THRESHOLD))
+		return false;
 
 	/*
 	 * Some divecomputers give "surface" events that just aren't interesting.
@@ -229,9 +218,13 @@ bool DiveEventItem::shouldBeHidden()
 	if (!strcmp(ev->name, "surface")) {
 		int time = ev->time.seconds;
 		if (time <= 30 || time + 30 >= (int)dc->duration.seconds)
-			return true;
+			return false;
 	}
+	return true;
+}
 
+bool DiveEventItem::shouldBeHidden()
+{
 	for (int i = 0; i < evn_used; i++) {
 		if (!strcmp(ev->name, ev_namelist[i].ev_name) && ev_namelist[i].plot_ev == false)
 			return true;
@@ -239,39 +232,17 @@ bool DiveEventItem::shouldBeHidden()
 	return false;
 }
 
-int DiveEventItem::depthAtTime(int time)
-{
-	QModelIndexList result = dataModel->match(dataModel->index(0, DivePlotDataModel::TIME), Qt::DisplayRole, time);
-	if (result.isEmpty()) {
-		qWarning("can't find a spot in the dataModel");
-		hide();
-		return DEPTH_NOT_FOUND;
-	}
-	return dataModel->data(dataModel->index(result.first().row(), DivePlotDataModel::DEPTH)).toInt();
-}
-
-void DiveEventItem::recalculatePos(int speed)
+void DiveEventItem::recalculatePos()
 {
 	if (!ev)
 		return;
 
-	QModelIndexList result = dataModel->match(dataModel->index(0, DivePlotDataModel::TIME), Qt::DisplayRole, ev->time.seconds);
-	if (result.isEmpty()) {
-		qWarning("can't find a spot in the dataModel");
+	if (depth == DEPTH_NOT_FOUND) {
 		hide();
 		return;
 	}
-	int depth = depthAtTime(ev->time.seconds);
-	if (depth == DEPTH_NOT_FOUND)
-		return;
-	if (!isVisible() && !shouldBeHidden())
-		show();
-	qreal x = hAxis->posAtValue(ev->time.seconds);
-	qreal y = vAxis->posAtValue(depth);
-	if (speed > 0)
-		Animations::moveTo(this, speed, x, y);
-	else
-		setPos(x, y);
-	if (isVisible() && shouldBeHidden())
-		hide();
+	setVisible(!shouldBeHidden());
+	double x = hAxis->posAtValue(ev->time.seconds);
+	double y = vAxis->posAtValue(depth);
+	setPos(x, y);
 }
