@@ -31,7 +31,7 @@ QMLProfile::~QMLProfile()
 
 void QMLProfile::createProfileView()
 {
-	m_profileWidget.reset(new ProfileScene(m_devicePixelRatio, false, false));
+	m_profileWidget.reset(new ProfileScene(m_devicePixelRatio * 0.8, false, false));
 }
 
 // we need this so we can connect update() to the scaleChanged() signal - which the connect above cannot do
@@ -51,7 +51,10 @@ void QMLProfile::paint(QPainter *painter)
 		timer.start();
 
 	// let's look at the intended size of the content and scale our scene accordingly
+	// for some odd reason the painter transformation is set up to scale by the dpr - which results
+	// in applying that dpr scaling twice. So we hard-code it here to be the identity matrix
 	QRect painterRect = painter->viewport();
+	painter->resetTransform();
 	if (m_diveId < 0)
 		return;
 	struct dive *d = get_dive_by_uniq_id(m_diveId);
