@@ -35,6 +35,7 @@ static const double selectionLassoWidth = 2.0;		// Border between title and char
 
 StatsView::StatsView(QQuickItem *parent) : QQuickItem(parent),
 	backgroundDirty(true),
+	currentTheme(&getStatsTheme(false)),
 	highlightedSeries(nullptr),
 	xAxis(nullptr),
 	yAxis(nullptr),
@@ -53,9 +54,6 @@ StatsView::StatsView(QQuickItem *parent) : QQuickItem(parent),
 
 	setAcceptHoverEvents(true);
 	setAcceptedMouseButtons(Qt::LeftButton);
-
-	QFont font;
-	titleFont = QFont(font.family(), font.pointSize(), QFont::Light);	// Make configurable
 }
 
 StatsView::StatsView() : StatsView(nullptr)
@@ -99,7 +97,7 @@ void StatsView::mousePressEvent(QMouseEvent *event)
 		if (selectionRect)
 			deleteChartItem(selectionRect); // Ooops. Already a selection in place.
 		dragStartMouse = pos;
-		selectionRect = createChartItem<ChartRectLineItem>(ChartZValue::Selection, selectionLassoColor, selectionLassoWidth);
+		selectionRect = createChartItem<ChartRectLineItem>(ChartZValue::Selection, currentTheme->selectionLassoColor, selectionLassoWidth);
 		selectionModifier = modifier;
 		oldSelection = modifier.ctrl ? getDiveSelection() : std::vector<dive *>();
 		grabMouse();
@@ -143,7 +141,7 @@ RootNode::RootNode(StatsView &view) : view(view)
 	// also be done on the widget level, but would have to be done
 	// separately for desktop and mobile, so do it here.
 	backgroundNode.reset(view.w()->createRectangleNode());
-	backgroundNode->setColor(backgroundColor);
+	backgroundNode->setColor(view.getCurrentTheme().backgroundColor);
 	appendChildNode(backgroundNode.get());
 
 	for (auto &zNode: zNodes) {
@@ -184,7 +182,7 @@ QSGNode *StatsView::updatePaintNode(QSGNode *oldNode, QQuickItem::UpdatePaintNod
 	}
 
 	for (ChartItem *item = dirtyItems.first; item; item = item->next) {
-		item->render();
+		item->render(*currentTheme);
 		item->dirty = false;
 	}
 	dirtyItems.splice(cleanItems);
@@ -299,6 +297,17 @@ QQuickWindow *StatsView::w() const
 	return window();
 }
 
+void StatsView::setTheme(bool dark)
+{
+	currentTheme = &getStatsTheme(dark);
+	rootNode->backgroundNode->setColor(currentTheme->backgroundColor);
+}
+
+const StatsTheme &StatsView::getCurrentTheme() const
+{
+	return *currentTheme;
+}
+
 QSizeF StatsView::size() const
 {
 	return boundingRect().size();
@@ -309,14 +318,22 @@ QRectF StatsView::plotArea() const
 	return plotRect;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void StatsView::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
+#else
 void StatsView::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+#endif
 {
 	plotRect = QRectF(QPointF(0.0, 0.0), newGeometry.size());
 	backgroundDirty = true;
 	plotAreaChanged(plotRect.size());
 
 	// Do we need to call the base-class' version of geometryChanged? Probably for QML?
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	QQuickItem::geometryChange(newGeometry, oldGeometry);
+#else
 	QQuickItem::geometryChanged(newGeometry, oldGeometry);
+#endif
 }
 
 void StatsView::plotAreaChanged(const QSizeF &s)
@@ -450,8 +467,8 @@ void StatsView::setTitle(const QString &s)
 		// Ooops. Currently we do not support setting the title twice.
 		return;
 	}
-	title = createChartItem<ChartTextItem>(ChartZValue::Legend, titleFont, s);
-	title->setColor(darkLabelColor);
+	title = createChartItem<ChartTextItem>(ChartZValue::Legend, currentTheme->titleFont, s);
+	title->setColor(currentTheme->darkLabelColor);
 }
 
 void StatsView::updateTitlePos()
@@ -1120,10 +1137,10 @@ void StatsView::plotHistogramCountChart(const std::vector<dive *> &dives,
 	if (categoryVariable->type() == StatsVariable::Type::Numeric) {
 		double mean = categoryVariable->mean(dives);
 		if (!std::isnan(mean))
-			meanMarker = createChartItem<HistogramMarker>(mean, isHorizontal, meanMarkerColor, xAxis, yAxis);
+			meanMarker = createChartItem<HistogramMarker>(mean, isHorizontal, currentTheme->meanMarkerColor, xAxis, yAxis);
 		double median = categoryVariable->quartiles(dives).q2;
 		if (!std::isnan(median))
-			medianMarker = createChartItem<HistogramMarker>(median, isHorizontal, medianMarkerColor, xAxis, yAxis);
+			medianMarker = createChartItem<HistogramMarker>(median, isHorizontal, currentTheme->medianMarkerColor, xAxis, yAxis);
 	}
 }
 
